@@ -3,7 +3,7 @@
 from aiida.cmdline.params.arguments import OverridableArgument
 from .types import PseudoPotentialFamilyParam
 
-__all__ = ('PSEUDO_POTENTIAL_FAMILY')
+__all__ = ('PSEUDO_POTENTIAL_FAMILY',)
 
 PSEUDO_POTENTIAL_FAMILY = OverridableArgument(
     'family', type=PseudoPotentialFamilyParam(sub_classes=('aiida.groups:pseudo.family',))
