@@ -4,11 +4,13 @@ import collections
 import json
 import os
 import re
+import warnings
+
+from pathlib import Path
 from typing import Sequence
 
 from aiida.common.exceptions import ParsingError
 
-from aiida_pseudo.common import units
 from aiida_pseudo.data.pseudo import UpfData, PsmlData, Psp8Data, JthXmlData
 from ..mixins import RecommendedCutoffMixin
 from .pseudo import PseudoPotentialFamily
@@ -21,13 +23,14 @@ PseudoDojoConfiguration = collections.namedtuple(
 
 
 class PseudoDojoFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
-    """Subclass of `PseudoPotentialFfamily` designed to represent a PseudoDojo configuration.
+    """Subclass of ``PseudoPotentialFamily`` designed to represent a PseudoDojo configuration.
 
-    The `PseudoDojoFamily` is essentially a `PseudoPotentialFfamily` with some additional constraints. It can only be
-    used to contain the pseudo potentials and corresponding metadata of an official PseudoDojo configuration.
+    The ``PseudoDojoFamily`` is essentially a ``PseudoPotentialFamily`` with some additional constraints. It can only
+    be used to contain the pseudo potentials and corresponding metadata of an official PseudoDojo configuration.
     """
 
     _pseudo_types = (UpfData, PsmlData, Psp8Data, JthXmlData)
+    _pseudo_repo_file_extensions = ('djrepo',)
 
     label_template = 'PseudoDojo/{version}/{functional}/{relativistic}/{protocol}/{pseudo_format}'
     default_configuration = PseudoDojoConfiguration('0.4', 'PBE', 'SR', 'standard', 'psp8')
@@ -230,9 +233,7 @@ class PseudoDojoFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
             except KeyError as exception:
                 raise ParsingError(f'stringency `{stringency}` is not defined in the djrepo `hints`') from exception
 
-            ecutwfc = ecutwfc * units.HA_TO_EV
-            ecutrho = ecutwfc * dual
-            cutoffs[stringency] = {'cutoff_wfc': ecutwfc, 'cutoff_rho': ecutrho}
+            cutoffs[stringency] = {'cutoff_wfc': ecutwfc, 'cutoff_rho': ecutwfc * dual}
 
         return cutoffs
 
@@ -269,6 +270,11 @@ class PseudoDojoFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
             if not os.path.isfile(filepath):
                 raise ValueError(f'dirpath `{dirpath}` contains at least one entry that is not a file')
 
+            # Some of the djrepo archives contain extraneous files. Here we skip files with unsupported extensions.
+            if filename.split('.')[-1] not in cls._pseudo_repo_file_extensions:
+                warnings.warn(f'filename {filename} does not have a supported extension. Skipping...')
+                continue
+
             try:
                 with open(filepath, 'r') as handle:
                     djrepo = json.load(handle)
@@ -310,7 +316,7 @@ class PseudoDojoFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
         return md5s, cutoffs
 
     @classmethod
-    def parse_djrepos_from_archive(cls, filepath_metadata, fmt=None, pseudo_type=None):
+    def parse_djrepos_from_archive(cls, filepath_metadata: Path, fmt=None, pseudo_type=None):
         """Parse metadata from a djrepo .tgz archive.
 
         .. warning:: the archive should not contain any subdirectories, but just the djrepo files.
@@ -329,7 +335,8 @@ class PseudoDojoFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
 
         with tempfile.TemporaryDirectory() as dirpath:
             try:
-                shutil.unpack_archive(filepath_metadata, dirpath, format=fmt)
+                # In Python 3.6 the ``unpack_archive`` method does not yet support ``pathlib.Path`` objects.
+                shutil.unpack_archive(str(filepath_metadata), dirpath, format=fmt)
             except shutil.ReadError as exception:
                 raise OSError(
                     f'failed to unpack the metadata archive `{filepath_metadata}`: {exception}'
