@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Subclass of ``PseudoPotentialFamily`` designed to represent an SSSP configuration."""
 from collections import namedtuple
-from typing import Sequence
+from typing import Sequence, Optional
 
 from aiida_pseudo.data.pseudo import UpfData
 from ..mixins import RecommendedCutoffMixin
@@ -50,15 +50,23 @@ class SsspFamily(RecommendedCutoffMixin, PseudoPotentialFamily):
         )
 
     @classmethod
-    def format_configuration_filename(cls, configuration: SsspConfiguration, extension: str) -> str:
+    def format_configuration_filename(
+        cls, configuration: SsspConfiguration, extension: str, patch_version: Optional[str] = None
+    ) -> str:
         """Format the filename for a file of a particular SSSP configuration as it is available from MC Archive.
 
         :param configuration: the SSSP configuration.
         :param extension: the filename extension without the leading dot.
+        :param patch_version: patch version of the files which overrides the ``version`` specified in the
+            ``configuration``. This is necessary because we only let users specify the minor version, not install
+            configurations with a specific patch version. The filename on the archive however will contain the patch
+            version, so this needs to be substituted.
         :return: filename
         """
+        version = configuration.version if patch_version is None else patch_version
+
         return cls.filename_template.format(
-            version=configuration.version, functional=configuration.functional, protocol=configuration.protocol
+            version=version, functional=configuration.functional, protocol=configuration.protocol
         ) + f'.{extension}'
 
     def __init__(self, label=None, **kwargs):
